function Out = QualityIndices(I_HS,I_REF,ratio,mask)
%--------------------------------------------------------------------------
% Quality Indices
%
% USAGE
%   Out = QualityIndices(I_HS,I_REF,ratio)
%
% INPUT
%   I_HS  : target HS data (rows,cols,bands)
%   I_REF : reference HS data (rows,cols,bands)
%   ratio : GSD ratio between HS and MS imagers
%
% OUTPUT
%   Out.psnr : PSNR
%   Out.sam  : SAM
%   Out.cc   : CC
%   Out.rmse : RMSE
%   Out.ergas: ERGAS
%--------------------------------------------------------------------------

if nargin == 4
    cc = CC(I_HS,I_REF,mask);
    Out.cc = mean(cc);
    [angle_SAM,map] = SAM(I_HS,I_REF);
    Out.sam_map = map;
    Out.sam = mean(map(mask>0))*180/pi;
    rmse = RMSE(I_HS,I_REF,mask);
    Out.rmse = rmse.ave;
    Out.rmse_map = rmse.rmse_map;
    Out.ergas = ERGAS(I_HS,I_REF,ratio,mask);
    psnr = PSNR(I_HS,I_REF,mask);
    Out.psnr = psnr.ave;
    
    disp(['PSNR  : ' num2str(Out.psnr)]);
    disp(['SAM   : ' num2str(Out.sam)]);
    disp(['CC    : ' num2str(Out.cc)]);
    disp(['RMSE  : ' num2str(Out.rmse)]);
    disp(['ERGAS : ' num2str(Out.ergas)]);
    
else
   
    cc = CC(I_HS,I_REF);
    Out.cc = mean(cc);
    [angle_SAM,map] = SAM(I_HS,I_REF);
    Out.sam = angle_SAM;
    Out.rmse = RMSE(I_HS,I_REF);
    Out.ergas = ERGAS(I_HS,I_REF,ratio);
    psnr = PSNR(I_HS,I_REF);
    Out.psnr = psnr.ave;

    disp(['PSNR  : ' num2str(Out.psnr)]);
    disp(['SAM   : ' num2str(Out.sam)]);
    disp(['CC    : ' num2str(Out.cc)]);
    disp(['RMSE  : ' num2str(Out.rmse)]);
    disp(['ERGAS : ' num2str(Out.ergas)]);
    
end
